@@ -14,6 +14,7 @@
 
 import ddt
 import mock
+import six
 
 from os_win import constants
 from os_win import exceptions
@@ -118,6 +119,18 @@ class VMUtils10TestCase(test_base.OsWinBaseTestCase):
                           1, constants.REMOTEFX_MAX_RES_1024x768,
                           vram_bytes=10000)
 
+    def test_validate_remotefx(self):
+        self._vmutils._validate_remotefx_params(
+            1, constants.REMOTEFX_MAX_RES_1024x768)
+
+    def test_set_remotefx_vram(self):
+        remotefx_ctrl_res = mock.MagicMock()
+        vram_bytes = 512
+
+        self._vmutils._set_remotefx_vram(remotefx_ctrl_res, vram_bytes)
+        self.assertEqual(six.text_type(vram_bytes),
+                         remotefx_ctrl_res.VRAMSizeBytes)
+
     @mock.patch.object(vmutils10.VMUtils10, 'get_vm_generation')
     def _test_vm_has_s3_controller(self, vm_gen, mock_get_vm_gen):
         mock_get_vm_gen.return_value = vm_gen
@@ -319,3 +332,20 @@ class VMUtils10TestCase(test_base.OsWinBaseTestCase):
             vmsettings.InstanceID)
         self._vmutils._jobutils.remove_virt_resource.assert_called_once_with(
             pci_setting_data)
+
+    @mock.patch.object(_wqlutils, 'get_element_associated_class')
+    @mock.patch.object(vmutils10.VMUtils10, '_lookup_vm_check')
+    def test_remove_all_pci_devices(self, mock_lookup_vm_check,
+                                    mock_get_element_associated_class):
+        vmsettings = mock_lookup_vm_check.return_value
+
+        self._vmutils.remove_all_pci_devices(mock.sentinel.vm_name)
+
+        mock_lookup_vm_check.assert_called_once_with(mock.sentinel.vm_name)
+        mock_get_element_associated_class.assert_called_once_with(
+            self._vmutils._conn, self._vmutils._PCI_EXPRESS_SETTING_DATA,
+            vmsettings.InstanceID)
+        mock_remove_multiple_virt_resource = (
+            self._vmutils._jobutils.remove_multiple_virt_resources)
+        mock_remove_multiple_virt_resource.assert_called_once_with(
+            mock_get_element_associated_class.return_value)
